@@ -1,4 +1,6 @@
-from http_misc import http_utils, services
+from http_misc import http_utils, services, retry_policy
+
+policy = retry_policy.AsyncRetryPolicy()
 
 
 class AuthorizationGateway:
@@ -22,7 +24,7 @@ class AuthorizationGateway:
             }
         }
 
-        response_data = await http_utils.send_and_validate(services.HttpService(), request)
+        response_data = await http_utils.send_and_validate(services.HttpService(), request, policy=policy)
         if 'token' not in response_data:
             raise KeyError('Invalid response. Token is absent.')
 
